/**
 *
 * TSSRemoteorDirect is a Java test script that can be executed within
 * TestManager, or detached from TestManager.
 *
 * The script demonstrates some typical Test Script Services by executing
 * and measuring two delay calls.
 *
 * The script can be executed detached from TestManager using TSS Remote.
 * The Java system property rt.tssremote.java controls whether the script
 * uses the TSS Direct or TSS Remote libraries.  A TSS Remote script must
 * make the additional step of connecting to the TestManger TSS listener
 * prior to executing any TSS calls.
 *
 * To execute this script from TestManager:
 * 1) Create a Java test script source in TestManager.
 * 2) Copy this test script to the source directory.
 * 3) Create a performance test suite and insert this Java test script.
 *
 * To execute this script detached from TestManager:
 * 1) Create a directory and copy this test script to that directory.
 *    d:\>mkdir testremote
 *    d:\>copy TSSRemoteorDirect.java d:\testremote
 * 2) Compile the test script.
 *    d:\>cd testremote
 *    d:\testremote>javac -classpath "d:\program files\rational\rational test\rttssjava.jar;d:\testremote" TSSRemoteorDirect.java
 * 3) Create a performance test suite and insert a Command Line script:
 *    Program to execute:  java.exe
 *    Command line arguments:  -Drt.tssjava.remote=true -cp "d:\program files\rational\rational test\rttssjava.jar;d:\testremote" TSSRemoteorDirect
 *
 * Sections of the script required for TSS Remote are marked as follows:
 *      // BEGIN REQUIRED FOR TSS REMOTE
 *      // END REQUIRED FOR TSS REMOTE
 *
 *
 * @author Kevin Mooney
 * @version 1.0, 23-Sep-2002
 *
 *
 * Revision History
 * Programmer          Date        Revision
 * ==========================================================================
 *
 *
 * Copyright  2002 Rational Software Corporation.  All Rights Reserved.
 * Rational Software Corporation Prorietary and Confidential.
 *
 */

import java.io.*;
import com.rational.test.tss.*;

public class TSSRemoteorDirect extends com.rational.test.tss.TestScript {


    // BEGIN REQUIRED FOR TSS REMOTE

    public boolean tssConnect() {
        try {
            String host = TSSUtility.getEnv("RTTSS_HOST");
            Integer port = new Integer(TSSUtility.getEnv("RTTSS_PORT"));
            Integer vtid = new Integer(TSSUtility.getEnv("RTTSS_VTID"));
            int rc = TSSSession.connect(host,
                                        port.intValue(),
                                        vtid.intValue());
            if (rc == 0)
                return true;
            else return false;
        } catch (Exception e) {
            e.printStackTrace();
            return false;
        }
    }
    // END REQUIRED FOR TSS REMOTE


    public void testMain(String[] args) {
        try {
            com.rational.test.tss.TSSNamedValue[] b = null;


            // BEGIN REQUIRED FOR TSS REMOTE

            String remote = System.getProperty("rt.tssjava.remote");
            if (remote != null && remote.equals("true"))
                tssConnect();
            // END REQUIRED FOR TSS REMOTE


            TSSMeasure.commandStart("step001", "step001", MST_DELAY);
            TSSUtility.delay(2000);
            TSSMeasure.commandEnd(TSS_LOG_RESULT_PASS,
                                  "fail",
                                  0,
                                  0,
                                  "Delayed 2 seconds",
                                  b);

            TSSMeasure.commandStart("step002", "step002", MST_DELAY);
            TSSUtility.delay(3000);
            TSSMeasure.commandEnd(TSS_LOG_RESULT_PASS,
                                  "fail",
                                  0,
                                  0,
                                  "Delayed 3 seconds",
                                  b);
        } catch(Exception e) {
            e.printStackTrace();
        }
    }

    public static void main(String[] args) {
        TSSRemoteorDirect h = new TSSRemoteorDirect();
        h.testMain(args);
    }
}
